// src/main.cc - Copyright 2005, 2006, University
//               of Padova, dept. of Pure and Applied
//               Mathematics
//
// This file is part of SGPEMv2.
//
// This is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// SGPEMv2 is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with SGPEMv2; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

#include "config.h"
#include "gettext.h"

#include "main.hh"
#include "parseopts.hh"
#include "gtkgui/startgui.hh"

#include <algorithm>
#include <functional>
#include <iostream>
#include <iterator>
#include <string>
#include <vector>


// Functor to be used by for_each()
struct create_fnames_vect : public std::unary_function<const char*, void> 
{
  typedef std::vector<std::string>& vect_type;
public:
  create_fnames_vect(vect_type v) : _v(v) {}
  void operator()(const char* str) {_v.push_back(str);}
private:
  vect_type _v;
};


int 
main(int argc, char* argv[]) 
{
  using namespace std;

  // Set up gettext support
  setlocale(LC_ALL, "");
  bindtextdomain(PACKAGE, LOCALEDIR);
  textdomain(PACKAGE);

  // Parses options and prepares vector with 
  // filenames of documents to be opened
  vector<string> filenames;
  {
    int a_count  = argc;
    char** a_ptr = argv;
    parse_options(a_count, a_ptr);
    for_each(a_ptr, a_ptr+a_count, create_fnames_vect(filenames));
  }

  start_gui(argc, argv);

  return 0;
}
